# Examples

Simple use cases that demonstrate the main features.

## [Docker Entry Point](./entrypoint)

Molot is useful for creating entry points in your Docker images.

## [Build Packager](./packager)

You can use Molot for orchestrating simple build tasks in your project.
